@@ -16,7 +16,9 @@ from dbt_cloud.command import (
     DbtCloudMetadataQueryCommand,
     DbtCloudRunListCommand,
     DbtCloudJobListCommand,
+    DbtCloudProjectListCommand,
 )
+from dbt_cloud.demo import data_catalog
 from dbt_cloud.serde import json_to_dict, dict_to_json
 from dbt_cloud.exc import DbtCloudException
 
@@ -49,17 +51,22 @@ def dbt_cloud():
         http_client.HTTPConnection.debuglevel = 1
 
 
-@dbt_cloud.group()
+@dbt_cloud.group(help="dbt Cloud job commands")
 def job():
     pass
 
 
-@dbt_cloud.group(name="run")
+@dbt_cloud.group(name="run", help="dbt Cloud run commands")
 def job_run():
     pass
 
 
-@dbt_cloud.group()
+@dbt_cloud.group(help="dbt Cloud project commands")
+def project():
+    pass
+
+
+@dbt_cloud.group(help="dbt Cloud Metadata API commands")
 def metadata():
     pass
 
@@ -257,6 +264,13 @@ def get_artifact(file, **kwargs):
     response.raise_for_status()
 
 
+@project.command(help=DbtCloudProjectListCommand.get_description())
+@DbtCloudProjectListCommand.click_options
+def list(**kwargs):
+    command = DbtCloudProjectListCommand.from_click_options(**kwargs)
+    response = execute_and_print(command)
+
+
 @metadata.command(help=DbtCloudMetadataQueryCommand.get_description())
 @click.option(
     "-f",
@@ -271,3 +285,11 @@ def query(file, **kwargs):
         query=file.read(), **kwargs
     )
     execute_and_print(command)
+
+
+@dbt_cloud.group(help="Demo applications")
+def demo():
+    pass
+
+
+demo.add_command(data_catalog)
